==> haskell-wai-websockets-3.0.1.2-68-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-websockets
version: 3.0.1.2
id: wai-websockets-3.0.1.2-5SoNs6lBMOw6aSdSAGu2KQ
key: wai-websockets-3.0.1.2-5SoNs6lBMOw6aSdSAGu2KQ
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.
category: Web, Yesod
abi: 4c5c24a997a183124ea834adc40b16e3
exposed: True
exposed-modules:
    Network.Wai.Handler.WebSockets
import-dirs: /usr/lib/ghc-8.6.4/site-local/wai-websockets-3.0.1.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/wai-websockets-3.0.1.2
hs-libraries: HSwai-websockets-3.0.1.2-5SoNs6lBMOw6aSdSAGu2KQ
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    http-types-0.12.3-7ETbM18iSLZB08qGmmgPmt
    network-2.8.0.0-65TWeU8omLsDYfm0yvOQxG transformers-0.5.6.2
    wai-3.2.2-7UZCsmzPTqFA7VskjtEotY
    websockets-0.12.5.3-Fpv4uiHWHptIlsMIZJCc5j
haddock-interfaces: /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock
haddock-html: /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-websockets-3.0.1.2-69-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-websockets
version: 3.0.1.2
id: wai-websockets-3.0.1.2-I63hzaD4OCyJ49OT88scq0
key: wai-websockets-3.0.1.2-I63hzaD4OCyJ49OT88scq0
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.
category: Web, Yesod
abi: c5b3bdce7eb744106ca90a105753b5db
exposed: True
exposed-modules:
    Network.Wai.Handler.WebSockets
import-dirs: /usr/lib/ghc-8.6.4/site-local/wai-websockets-3.0.1.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/wai-websockets-3.0.1.2
hs-libraries: HSwai-websockets-3.0.1.2-I63hzaD4OCyJ49OT88scq0
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    http-types-0.12.3-IdIFkPvozmRFdXetXaEgxE
    network-2.8.0.0-58b93NZ1Nmb3T9F5Ys3Y7W transformers-0.5.6.2
    wai-3.2.2-6o6QSnPVpAu2Kn1dd7YFx6
    websockets-0.12.5.3-GXOG1FjvhlhEg3NnWwxP9M
haddock-interfaces: /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock
haddock-html: /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
